//////////////////////////////////////////////////////////////////////////////
// Name:        SVGNumber.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_NUMBER_H
#define WX_SVG_NUMBER_H

class wxSVGNumber
{
  protected:
    double m_value;

  public:
    inline double GetValue() const { return m_value; }
    inline void SetValue(double n) { m_value = n; }

  public:
    wxSVGNumber(): m_value(0) {}
    wxSVGNumber(double value): m_value(value) {}
    virtual ~wxSVGNumber() {}
};

#endif // WX_SVG_NUMBER_H
