//////////////////////////////////////////////////////////////////////////////
// Name:        SVGAnimatedInteger.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genAnimated.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_ANIMATED_INTEGER_H
#define WX_SVG_ANIMATED_INTEGER_H


class wxSVGAnimatedInteger
{
  public:
    wxSVGAnimatedInteger(): m_baseVal(0), m_animVal(0) {}
	wxSVGAnimatedInteger(long value): m_baseVal(value), m_animVal(value) {}
	
    inline long GetBaseVal() const { return m_baseVal; };
	inline void SetBaseVal(long value) { m_baseVal = m_animVal = value; }
	
    inline long GetAnimVal() const { return m_animVal; }
	inline void SetAnimVal(long value) { m_animVal = value; }
    
  public:
    inline operator long() const { return GetAnimVal(); }
    
  protected:
    long m_baseVal;
    long m_animVal;
};


#endif // WX_SVG_ANIMATED_INTEGER_H
