//////////////////////////////////////////////////////////////////////////////
// Name:        SVGDTD.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genSvgElement.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_DT_D_H
#define WX_SVG_DT_D_H

enum wxSVGDTD
{
  wxSVG_A_ELEMENT,
  wxSVG_ALTGLYPH_ELEMENT,
  wxSVG_ALTGLYPHDEF_ELEMENT,
  wxSVG_ALTGLYPHITEM_ELEMENT,
  wxSVG_ANIMATE_ELEMENT,
  wxSVG_ANIMATECOLOR_ELEMENT,
  wxSVG_ANIMATEMOTION_ELEMENT,
  wxSVG_ANIMATETRANSFORM_ELEMENT,
  wxSVG_CIRCLE_ELEMENT,
  wxSVG_CLIPPATH_ELEMENT,
  wxSVG_COLOR_PROFILE_ELEMENT,
  wxSVG_CURSOR_ELEMENT,
  wxSVG_DEFINITION_SRC_ELEMENT,
  wxSVG_DEFS_ELEMENT,
  wxSVG_DESC_ELEMENT,
  wxSVG_ELLIPSE_ELEMENT,
  wxSVG_FEBLEND_ELEMENT,
  wxSVG_FECOLORMATRIX_ELEMENT,
  wxSVG_FECOMPONENTTRANSFER_ELEMENT,
  wxSVG_FECOMPOSITE_ELEMENT,
  wxSVG_FECONVOLVEMATRIX_ELEMENT,
  wxSVG_FEDIFFUSELIGHTING_ELEMENT,
  wxSVG_FEDISPLACEMENTMAP_ELEMENT,
  wxSVG_FEDISTANTLIGHT_ELEMENT,
  wxSVG_FEFLOOD_ELEMENT,
  wxSVG_FEFUNCA_ELEMENT,
  wxSVG_FEFUNCB_ELEMENT,
  wxSVG_FEFUNCG_ELEMENT,
  wxSVG_FEFUNCR_ELEMENT,
  wxSVG_FEGAUSSIANBLUR_ELEMENT,
  wxSVG_FEIMAGE_ELEMENT,
  wxSVG_FEMERGE_ELEMENT,
  wxSVG_FEMERGENODE_ELEMENT,
  wxSVG_FEMORPHOLOGY_ELEMENT,
  wxSVG_FEOFFSET_ELEMENT,
  wxSVG_FEPOINTLIGHT_ELEMENT,
  wxSVG_FESPECULARLIGHTING_ELEMENT,
  wxSVG_FESPOTLIGHT_ELEMENT,
  wxSVG_FETILE_ELEMENT,
  wxSVG_FETURBULENCE_ELEMENT,
  wxSVG_FILTER_ELEMENT,
  wxSVG_FONT_ELEMENT,
  wxSVG_FONT_FACE_ELEMENT,
  wxSVG_FONT_FACE_FORMAT_ELEMENT,
  wxSVG_FONT_FACE_NAME_ELEMENT,
  wxSVG_FONT_FACE_SRC_ELEMENT,
  wxSVG_FONT_FACE_URI_ELEMENT,
  wxSVG_FOREIGNOBJECT_ELEMENT,
  wxSVG_G_ELEMENT,
  wxSVG_GLYPH_ELEMENT,
  wxSVG_GLYPHREF_ELEMENT,
  wxSVG_HKERN_ELEMENT,
  wxSVG_IMAGE_ELEMENT,
  wxSVG_LINE_ELEMENT,
  wxSVG_LINEARGRADIENT_ELEMENT,
  wxSVG_MARKER_ELEMENT,
  wxSVG_MASK_ELEMENT,
  wxSVG_METADATA_ELEMENT,
  wxSVG_MISSING_GLYPH_ELEMENT,
  wxSVG_MPATH_ELEMENT,
  wxSVG_PATH_ELEMENT,
  wxSVG_PATTERN_ELEMENT,
  wxSVG_POLYGON_ELEMENT,
  wxSVG_POLYLINE_ELEMENT,
  wxSVG_RADIALGRADIENT_ELEMENT,
  wxSVG_RECT_ELEMENT,
  wxSVG_SCRIPT_ELEMENT,
  wxSVG_SET_ELEMENT,
  wxSVG_STOP_ELEMENT,
  wxSVG_STYLE_ELEMENT,
  wxSVG_SVG_ELEMENT,
  wxSVG_SWITCH_ELEMENT,
  wxSVG_SYMBOL_ELEMENT,
  wxSVG_TBREAK_ELEMENT,
  wxSVG_TEXT_ELEMENT,
  wxSVG_TEXTPATH_ELEMENT,
  wxSVG_TITLE_ELEMENT,
  wxSVG_TREF_ELEMENT,
  wxSVG_TSPAN_ELEMENT,
  wxSVG_USE_ELEMENT,
  wxSVG_VIDEO_ELEMENT,
  wxSVG_VIEW_ELEMENT,
  wxSVG_VKERN_ELEMENT,
  wxSVG_UNKNOWN_ELEMENT
};

#endif // WX_SVG_DT_D_H
