//////////////////////////////////////////////////////////////////////////////
// Name:        GetSVGDocument.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_GET_SVG_DOCUMENT_H
#define WX_GET_SVG_DOCUMENT_H

#include "SVGDocument.h"

class wxGetSVGDocument
{
  public:
    virtual ~wxGetSVGDocument() {}
    virtual wxSVGDocument* GetSVGDocument();
};

#endif // WX_GET_SVG_DOCUMENT_H
