//////////////////////////////////////////////////////////////////////////////
// Name:        SVGTransformList.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genList.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_TRANSFORM_LIST_H
#define WX_SVG_TRANSFORM_LIST_H

#include "SVGTransform.h"
#include "String_wxsvg.h"
#include <wx/dynarray.h>
WX_DECLARE_OBJARRAY(wxSVGTransform, wxSVGTransformListBase);

class wxSVGTransformList: public wxSVGTransformListBase
{
  public:
    wxSVGTransformList() {}
    
    wxString GetValueAsString() const;
    void SetValueAsString(const wxString& value);
};

#endif // WX_SVG_TRANSFORM_LIST_H
