//////////////////////////////////////////////////////////////////////////////
// Name:        Document.h
// Purpose:     
// Author:      Alex Thuering
// Created:     2005/04/28
// RCS-ID:      $Id: Document.h,v 1.4 2010/08/17 08:00:29 ntalex Exp $
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
//////////////////////////////////////////////////////////////////////////////

#ifndef wxSVG_DOCUMENT_H
#define wxSVG_DOCUMENT_H

#ifdef GetCurrentTime
#undef GetCurrentTime
#endif

#include "wxSVGXML/svgxml.h"

#endif //wxSVG_DOCUMENT_H

