//////////////////////////////////////////////////////////////////////////////
// Name:        SVGLengthList.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genList.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_LENGTH_LIST_H
#define WX_SVG_LENGTH_LIST_H

#include "SVGLength.h"
#include "String_wxsvg.h"
#include <wx/dynarray.h>
WX_DECLARE_OBJARRAY(wxSVGLength, wxSVGLengthListBase);

class wxSVGLengthList: public wxSVGLengthListBase
{
  public:
    wxSVGLengthList() {}
    
    wxString GetValueAsString() const;
    void SetValueAsString(const wxString& value);
};

#endif // WX_SVG_LENGTH_LIST_H
