//////////////////////////////////////////////////////////////////////////////
// Name:        SVGStringList.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by genList.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_STRING_LIST_H
#define WX_SVG_STRING_LIST_H

#include "String_wxsvg.h"
#include "String_wxsvg.h"
#include <wx/dynarray.h>
WX_DECLARE_OBJARRAY(wxString, wxSVGStringListBase);

class wxSVGStringList: public wxSVGStringListBase
{
  public:
    wxSVGStringList() {}
    
    wxString GetValueAsString(wxChar delimiter = wxT(',')) const;
    void SetValueAsString(const wxString& value, wxChar delimiter = wxT(','));
};

#endif // WX_SVG_STRING_LIST_H
