//////////////////////////////////////////////////////////////////////////////
// Name:        SVGPathSegClosePath.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_PATH_SEG_CLOSE_PATH_H
#define WX_SVG_PATH_SEG_CLOSE_PATH_H

#include "SVGPathSeg.h"

class wxSVGPathSegClosePath:
  public wxSVGPathSeg
{
  public:
    wxSVGPathSegClosePath():
      wxSVGPathSeg(wxPATHSEG_CLOSEPATH) {}
    virtual ~wxSVGPathSegClosePath() {}
};

#endif // WX_SVG_PATH_SEG_CLOSE_PATH_H
