//////////////////////////////////////////////////////////////////////////////
// Name:        SVGLangSpace.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_LANG_SPACE_H
#define WX_SVG_LANG_SPACE_H

#include "String_wxsvg.h"
#include "Element.h"

class wxSVGLangSpace
{
  protected:
    wxString m_xmllang;
    wxString m_xmlspace;

  public:
    inline const wxString& GetXmllang() const { return m_xmllang; }
    inline void SetXmllang(const wxString& n) { m_xmllang = n; }

    inline const wxString& GetXmlspace() const { return m_xmlspace; }
    inline void SetXmlspace(const wxString& n) { m_xmlspace = n; }

  public:
    virtual ~wxSVGLangSpace() {}
    bool HasAttribute(const wxString& name) const;
    wxString GetAttribute(const wxString& name) const;
    bool SetAttribute(const wxString& name, const wxString& value);
    wxSvgXmlAttrHash GetAttributes() const;
};

#endif // WX_SVG_LANG_SPACE_H
