//////////////////////////////////////////////////////////////////////////////
// Name:        SVGCSSRule.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_CSS_RULE_H
#define WX_SVG_CSS_RULE_H

#include "CSSRule.h"

class wxSVGCSSRule:
  public wxCSSRule
{
  public:
    virtual ~wxSVGCSSRule() {}
};

#endif // WX_SVG_CSS_RULE_H
