//////////////////////////////////////////////////////////////////////////////
// Name:        SVGColorProfileRule.h
// Author:      Alex Thuering
// Copyright:   (c) 2005 Alex Thuering
// Licence:     wxWindows licence
// Notes:       generated by generate.py
//////////////////////////////////////////////////////////////////////////////

#ifndef WX_SVG_COLOR_PROFILE_RULE_H
#define WX_SVG_COLOR_PROFILE_RULE_H

#include "SVGCSSRule.h"
#include "SVGRenderingIntent.h"
#include "String_wxsvg.h"

class wxSVGColorProfileRule:
  public wxSVGCSSRule,
  public wxSVGRenderingIntent
{
  protected:
    wxString m_src;
    wxString m_name;
    wxRENDERING_INTENT m_renderingIntent;

  public:
    inline const wxString& GetSrc() const { return m_src; }
    inline void SetSrc(const wxString& n) { m_src = n; }

    inline const wxString& GetName() const { return m_name; }
    inline void SetName(const wxString& n) { m_name = n; }

    inline wxRENDERING_INTENT GetRenderingIntent() const { return m_renderingIntent; }
    inline void SetRenderingIntent(const wxRENDERING_INTENT& n) { m_renderingIntent = n; }

  public:
    wxSVGColorProfileRule(): m_renderingIntent(wxRENDERING_INTENT(0)) {}
    virtual ~wxSVGColorProfileRule() {}
};

#endif // WX_SVG_COLOR_PROFILE_RULE_H
